Test Locators
open | ../tests/html/test_locators.html |
verifyText | id=id1 | this is the first element
verifyElementNotPresent | id=name1 |
verifyElementNotPresent | id=id4 |
verifyAttribute | id=id1@class | a1
verifyText | name=name1 | this is the second element
verifyElementNotPresent | name=id1 |
verifyElementNotPresent | name=notAName |
verifyAttribute | name=name1@class | a2
verifyText | class=a3 | this is the third element
verifyElementPresent | alt=banner |
verifyText | identifier=id1 | this is the first element
verifyElementNotPresent | identifier=id4 |
verifyAttribute | identifier=id1@class | a1
verifyText | identifier=name1 | this is the second element
verifyAttribute | identifier=name1@class | a2
verifyText | dom=document.links[1] | this is the second element
verifyText | dom=function foo() {return document.links[1];}; foo(); | this is the second element
verifyAttribute | dom=document.links[1]@class | a2
verifyElementNotPresent | dom=document.links[9] |
verifyElementNotPresent | dom=foo |
verifyElementPresent | link=this is the second element | a2
assertTextPresent | this is the second element |
verifyElementPresent | link=this * second element | a2
verifyElementPresent | link=regexp:this [aeiou]s the second element | a2
verifyAttribute | link=this is the second element@class | a2
verifyElementNotPresent | link=this is not an element |